"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _os = require("os");

var _getLog = _interopRequireDefault(require("../get-log"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const destroy = async (pool, options) => {
  const log = (0, _getLog.default)(`resource: destroy`);
  const {
    executeStatement: _executeStatement,
    connect: _connect,
    RDSDataService,
    escapeId,
    escape,
    fullJitter,
    coercer,
    dispose: _dispose
  } = pool;
  const connect = _connect;
  const executeStatement = _executeStatement;
  const dispose = _dispose;
  log.debug(`configuring adapter with environment privileges`);
  const adminPool = {
    config: {
      region: options.region,
      awsSecretStoreArn: options.awsSecretStoreAdminArn,
      dbClusterOrInstanceArn: options.dbClusterOrInstanceArn,
      databaseName: options.databaseName,
      eventsTableName: options.eventsTableName,
      secretsTableName: options.secretsTableName,
      snapshotsTableName: options.snapshotsTableName
    }
  };
  log.debug(`connecting the adapter`);
  await connect(adminPool, {
    RDSDataService,
    escapeId,
    escape,
    fullJitter,
    executeStatement,
    coercer
  });
  let alterSchemaError = null;
  let dropSchemaError = null;

  try {
    log.debug(`altering schema owner`);
    await executeStatement(adminPool, `ALTER SCHEMA ${escapeId(options.databaseName)} OWNER TO SESSION_USER`);
  } catch (error) {
    alterSchemaError = error;
  }

  try {
    log.debug(`dropping schema with all its tables`);
    await executeStatement(adminPool, `DROP SCHEMA ${escapeId(options.databaseName)} CASCADE`);
  } catch (error) {
    dropSchemaError = error;
  }

  if (alterSchemaError != null || dropSchemaError != null) {
    const error = new Error();
    error.message = `${alterSchemaError != null ? `${alterSchemaError.message}${_os.EOL}` : ''}${dropSchemaError != null ? `${dropSchemaError.message}${_os.EOL}` : ''}`;
    log.error(error.message);
    log.verbose(error.stack || error.message);
    throw error;
  }

  log.debug(`disposing the adapter`);
  await dispose(adminPool);
  log.debug(`resource destroyed successfully`);
};

var _default = destroy;
exports.default = _default;
//# sourceMappingURL=destroy.js.map